<template>
    <el-dialog
        v-if="dialogVisible"
        custom-class="easy-dialog"
        :visible.sync="dialogVisible"
        :show-close="false"
        top="2%"
        :append-to-body="true"
    >
        <!-- 关闭图标 -->
        <img
            class="cloes-icon"
            src="@/assets/img/easy-dialog/icon_tck_close@3x.png"
            @click="dialogVisible = false"
        />
        <div class="title-diy">
            <div class="title">
                {{ title }}
            </div>
        </div>
        <div class="file-list">
            <div
                class="file-item"
                v-for="(item, index) in options"
                :key="index"
            >
                <div title="点击预览" class="file-name">
                    {{ index + 1 + '.' + item.label }}
                </div>
                <div class="action">
                    <el-link
                        class="download"
                        @click="fileChange(item)"
                        :underline="false"
                        v-if="isHide"
                        >预览</el-link
                    >
                    <el-link
                        class="download"
                        @click="frontDownload(item)"
                        :underline="false"
                        >下载</el-link
                    >
                </div>
            </div>
        </div>
        <!-- 内容默认插槽 #01215a-->
        <div
            v-if="isHide"
            class="content-diy"
            v-loading="!show"
            element-loading-background="rgba(1, 33, 90, 1)"
        >
            <div id="docx" v-if="show">
                <Docx :fileUrl="fileUrl" :fileId="''"></Docx>
            </div>
        </div>
    </el-dialog>
</template>

<script>
import Docx from '@/components/docx'
export default {
    name: 'institutionalRule',
    components: {Docx},
    data() {
        return {
            title: '',
            fileUrl: '',
            dialogVisible: false,
            explain: [
                {
                    label: '有关说明',
                    value: './files/docx/有关说明.docx',
                    year: [2023],
                },
                // {
                //     label: '有关说明（2024）',
                //     value: './files/docx/有关说明（2024）.docx',
                //     year: [2024],
                // },
                {
                    label: '有关说明（202405）',
                    value: './files/docx/有关说明（202405）.docx',
                    year: [2024],
                },
                {
                    label: '202412版指标细则',
                    value: './files/docx/202412版指标细则.docx',
                    year: [2025],
                }

            ],
            audit: [
                {
                    label: '区县改革报表系统数据录入审核有关规范(3.0版)',
                    value: './files/docx/区县改革报表系统数据录入审核有关规范(3.0版).docx',
                    year: [2023],
                },
                // {
                //     label: '区县改革报表系统数据录入审核有关规范(4.0版)',
                //     value: './files/docx/区县改革报表系统数据录入审核有关规范(4.0版).docx',
                //     year: [2024],
                // },
                {
                    label: '区县改革报表系统数据录入审核有关规范(5.0版)',
                    value: './files/docx/区县改革报表系统数据录入审核有关规范(5.0版).docx',
                    year: [2024],
                },
            ],
            actions: [
                {
                    label: '区县改革报表填报系统操作说明及规范(3.0版)',
                    value: './files/docx/区县改革报表填报系统操作说明及规范(3.0版).docx',
                    year: [2023],
                },
                // {
                //     label: '区县改革报表填报系统操作说明及规范(4.0版)',
                //     value: './files/docx/区县改革报表填报系统操作说明及规范(4.0版).docx',
                //     year: [2024],
                // },
                {
                    label: '区县改革报表填报系统操作说明及规范(5.0版)',
                    value: './files/docx/区县改革报表填报系统操作说明及规范(5.0版).docx',
                    year: [2024],
                },
            ],
            formula: [
                {
                    label: '办结率和驳回率计算公式',
                    value: './files/docx/办结率和驳回率计算公式.docx',
                    year: [2023, 2024],
                },
            ],
            options: [],
            show: true,
            isHide:true
        }
    },
    methods: {
        setOptions() {
            this.options = []
            let {year} = JSON.parse(sessionStorage.getItem('searchDate'))
            if(year === 2025){
              this.isHide = false
            }
            let fileItem = this.explain.find((item) => item.year.includes(year))
            this.title = fileItem.label
            this.fileUrl = fileItem.value
            this.options.push(fileItem)
            this.options.push(
                this.audit.find((item) => item.year.includes(year))
            )
            this.options.push(
                this.actions.find((item) => item.year.includes(year))
            )
            this.options.push(
                this.formula.find((item) => item.year.includes(year))
            )

            this.options = this.options.filter(item => item !== undefined);
            console.log(this.options,'this.options')
        },
        open() {
            this.dialogVisible = true
            this.setOptions()
        },
        fileChange(item) {
            if (item.label !== this.title) {
                this.show = false
                this.fileUrl = item.value
                this.title = item.label
                setTimeout(() => {
                    this.show = true
                }, 500)
            }
        },
        frontDownload(item) {
            var a = document.createElement('a') // 创建一个<a></a>标签
            a.href = item.value
            a.download = item.label + '.docx' // 设置下载文件文件名
            a.style.display = 'none' // 隐藏a标签
            document.body.appendChild(a) // 将a标签追加到文档对象中
            a.click() // 模拟点击了a标签，会触发a标签的href的读取，浏览器就会自动下载了
            a.remove() // 一次性的，用完就删除a标签
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-input--suffix {
    text-align: center;
    border: none;

    .el-input__inner {
        border: none;
        background: transparent;
        color: #fff;
        padding: 0;
        text-align: center;
    }

    .el-select__caret {
        display: none;
    }
}

::v-deep .v-modal {
    display: none !important;
}

::v-deep .easy-dialog {
    //background: url("~@/assets/images/easy-dialog/dialog-bg.png") no-repeat;
    background-size: 100% 100%;
    box-sizing: border-box;
    border: 1px solid #0273E9;
    background-color: #01215a;
    padding-bottom: 26px;
    height: 90vh;
    width: 60%;

    .title-diy {
        width: 100%;
        height: 50px;
        display: flex;
        justify-content: center;
        align-items: center;
        // padding-left: 24px;
        box-sizing: border-box;

        .title {
            font-size: 18px;
            font-family: Source Han Sans CN;
            font-weight: 800;
            color: #FFFFFF;
            position: relative;
            text-shadow: 0px 0px 0.83333vw #266bf2;
        }

        .title::after,
        .title::before {
            content: '';
            position: absolute;
            top: 50%;
            width: 40px;
            height: 4px;
            transform: translateY(-50%);
        }

        .title::before {
            right: calc(100% + 20px);
            background: url('~@/assets/img/bigScreen/line63.png') no-repeat center / 100% 100%;
        }

        .title::after {
            left: calc(100% + 20px);
            background: url('~@/assets/img/bigScreen/line62.png') no-repeat center / 100% 100%;
        }
    }

    .el-dialog__body {
        max-height: 90vh !important
    }

    .file-list {
        // display: flex;
        justify-content: space-between;
        width: 100%;
        padding: 0 24px;
        box-sizing: border-box;

        .file-item {
            display: flex;
            justify-content: space-between;
            // width: 48%;
            line-height: 30PX;
            color: #fff;

            >* {
                font-size: 14PX !important;
            }

            .file-name {
                min-width: 75%;
                overflow: hidden;
                white-space: nowrap;
                text-overflow: ellipsis;
            }

            .action {
                width: 25%;
                text-align: right;
            }

            .el-link--inner {
                font-size: 14PX !important;
                vertical-align: top !important;
            }

            .download {
                cursor: pointer;
                color: #fff;
                border-radius: 2PX;
                // width: 70PX;
                height: 30PX;
                line-height: 30PX;
                text-align: center;

                &:first-child {
                    margin-right: 10PX;
                }

                &:hover {
                    color: #266bf2;
                    // color: #266bf2;
                }
            }
        }
    }


    .content-diy {
        box-sizing: border-box;
        // max-height: calc(900px - 44px - 30px);
        overflow-y: auto;
        padding: 0 24px;
        box-sizing: border-box;
        height: 65vh;


        /* 设置滚动条的样式 */
        &::-webkit-scrollbar {
            width: 8px !important; //垂直方向上的宽
            height: 8px !important; //水平方向上的宽
        }

        /* 滚动槽 */
        &::-webkit-scrollbar-track {
            border-radius: 0;
            background-color: #01215a !important;
        }

        /* 滚动条滑块 */
        &::-webkit-scrollbar-thumb {
            border-radius: 18px;
            background-color: rgba(#fff, 0.1) !important;
        }

        /*滚动条交叉样式*/
        &::-webkit-scrollbar-corner {
            background: #01215a !important;
        }
    }

    .footer-diy {
        display: flex;
        justify-content: center;
    }

    .el-dialog__header {
        width: 0;
        height: 0;
        padding: 0;
    }

    .el-dialog__body {
        padding: 0;
    }

    .cloes-icon {
        width: 20px;
        height: 20px;
        position: absolute;
        top: 6px;
        right: 6px;
        cursor: pointer;
    }

    .decoration {
        width: 100%;
        height: 100%;
        position: absolute;
        left: 0;
        top: 0;
    }
}
</style>
